//Use the strict rules for the backend
"use strict";

//Database and mail services libraries
require('dotenv').config();
const cors = require("cors");
const bodyParser = require("body-parser");
const mongoose = require("mongoose");
const reservationRoutes = require("./routes/reservations");
const userRoutes = require("./routes/users");
const passport = require('passport');
const fs = require('fs');

//Setup
const app = require("express")();

//Ref.: https://stackoverflow.com/questions/13448065/generating-an-ssl-key-to-work-with-node-js
// ##Certificate for SSL, remember to add options in create server ##
//const options = {
//    key: fs.readFileSync("/etc/letsencrypt/live/espensv-5min.uials.no/privkey.pem"),
//    cert: fs.readFileSync("/etc/letsencrypt/live/espensv-5min.uials.no/fullchain.pem")
//}

//Ref: https://socket.io/docs/v3/server-initialization/index.html
const httpServer = require("http").createServer(app);
const io = require("socket.io")(httpServer, {
    cors: {
        origin: "http://localhost:4200",
        methods: ["GET", "POST", "PATCH", "PUT", "DELETE", "OPTIONS"],
        transports: ['websocket', 'polling'],
        credentials: true
    },
    allowEIO3: true
});

//Ref: https://mongoosejs.com/docs/connections.html
//Connection to the database
mongoose
    .connect(
        process.env.MONGO_URI, {
            useNewUrlParser: true,
            useUnifiedTopology: true,
            useFindAndModify: false
        }
    )
    .then(() => {
        console.log("Connected to database!");
    })
    .catch(() => {
        console.log("Connection failed!");
    });

app.use(cors());

//Bodyparser
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({
    extended: true
}));

// Passport initializing
//Ref: https://stackoverflow.com/questions/46644366/what-is-passport-initialize-nodejs-express
app.use(passport.initialize());
app.use(passport.session());

//Express Session
app.use((req, res, next) => {
    res.setHeader("Access-Control-Allow-Origin", "*");
    res.setHeader(
        "Access-Control-Allow-Headers",
        "Origin, X-Requested-With, Content-Type, Accept, Authorization"
    );
    res.setHeader(
        "Access-Control-Allow-Methods",
        "GET, POST, PATCH, PUT, DELETE, OPTIONS"
    );
    next();
});

//Socket.io
//Ref: io.on("connection", socket => {
io.on("connection", socket => {
    socket.on('addReservation', newRes => {
        socket.broadcast.emit('updateReservationList', newRes);
    });
    socket.on('resNextUp', resInfo => {
        console.log('reservation in one hour', resInfo);
        setInterval(() => {
            socket.emit('alertRes', resInfo);
        }, 10 * 60000);
    });
    socket.on('disconnect', () => {
    });
});

//Ref: https://stackoverflow.com/questions/18864677/what-is-process-env-port-in-node-js/36974142
httpServer.listen(process.env.PORT, () => {
    console.log("Server is listening on port 3000")
});

// app.listen(8080);

app.use("/api/reservations", reservationRoutes);
app.use("", userRoutes);

module.exports = app;
