const Reservation = require("../models/reservation");

const ObjectID = require('mongodb').ObjectID;
const nodemailer = require("nodemailer");

/**
 * Ref: https://stackoverflow.com/questions/52368892/saving-a-string-in-mongodb-as-a-date-saves-wrong-values
 * @param req required
 * @param res result
 */
exports.createReservation = (req, res, next) => {
    const reservation = new Reservation({
        date: req.body.date,
        fromTime: req.body.fromTime,
        toTime: req.body.toTime,
        guestCounter: req.body.guestCounter,
        name: req.body.name,
        email: req.body.email,
        tableSelected: req.body.tableSelected,
        customMsg: req.body.customMsg,
        phoneNum: req.body.phoneNum,
        statusCheckbox: req.body.statusCheckbox
    });
    reservation.save().then(createdReservation => {
        res.status(201).json({
            message: "Reservation added successfully",
            reservationId: createdReservation._id
        });
        console.log("Reservation successfully added to database");
    });
    let user = req.body;
    sendMail(user, info => {
        console.log(`The mail has beed send 😃 and the id is ${info.messageId}`);
        res.send(info);
    });
}

/**
 * https://github.com/CodAffection/MEAN-Stack-CRUD-Operations/blob/master/NodeJS/controllers/employeeController.js
 */
exports.updateReservation = (req, res, next) => {
    if (!ObjectID.isValid(req.params.id)) {
        return res.status(400).send(`No record with given id: ${req.params.id}`);
    }

    var updatedStatus = req.body.statusCheckbox;
    if (updatedStatus.active) {
        updatedStatus = true;
    }

    var updatedReservation = {
        date: req.body.date,
        fromTime: req.body.fromTime,
        toTime: req.body.toTime,
        guestCounter: req.body.guestCounter,
        name: req.body.name,
        email: req.body.email,
        tableSelected: req.body.tableSelected,
        customMsg: req.body.customMsg,
        phoneNum: req.body.phoneNum,
        statusCheckbox: updatedStatus
    };

    Reservation.findByIdAndUpdate(
        req.params.id, {
            $set: updatedReservation
        }, {
            new: true
        },
        (err, doc) => {
            if (!err) {
                res.send(doc)
            } else {
                console.log('Error in reservation update: ' + JSON.stringify(err, undefined, 2));
            }
        });
}

exports.getReservation = (req, res, next) => {
    const pageSize = req.query.pageSize;
    const currentPage = req.query.page;
    const postQuery = Reservation.find();
    if (pageSize && currentpage) {
        postQuery
            .skip(pageSize * (currentPage - 1))
            .limit(pageSize);
    }
    Reservation.find({})
        .exec(function (error, reservations) {
            if (error) {
                console.log("Error retrieving data from DB")
            } else {
                res.json(reservations);
            }
        });
}

exports.deleteReservation = (req, res, next) => {
    console.log("Deleting a reservation")
    Reservation.findByIdAndRemove(req.params.id, function (error, deletedReservation) {
        if (error) {
            res.send("Something happend, cannot delete reservation!")
        } else {
            res.json(deletedReservation);
        }
    })
}

/**
 * Ref: https://stackoverflow.com/questions/56508261/nodemailer-email-confirmation-using-async-await
 * Ref, email: https://reallygoodemails.com/emails/appointment-confirmation-haircut-at-blind-barber/live
 */
// async..await is not allowed in global scope, must use a wrapper
async function sendMail(user, callback) {
    // Generate test SMTP service account from ethereal.email
    // Only needed if you don't have a real mail account for testing
    let testAccount = await nodemailer.createTestAccount();

    // create reusable transporter object using the default SMTP transport
    let transporter = nodemailer.createTransport({
        host: "smtp.gmail.com",
        port: 587,
        secure: false, // true for 465, false for other ports
        auth: {
            user: "cinqueminutibusiness@gmail.com", // generated ethereal user
            pass: "RistoranteItaliano", // generated ethereal password
        },
    });

    // send mail with defined transport object
    let info = await transporter.sendMail({
        from: '"🍕 5 Minuti, local authentic italian cuisine 🍕" <cinqueminutibusiness@gmail.com        >', // sender address
        to: `${user.email}, `, // list of receivers
        subject: "Table booking Reservation", // Subject line
        text: "", // plain text body
 // EMAIL REF: https://reallygoodemails.com/emails/appointment-confirmation-haircut-at-blind-barber/live
        html: `
<!DOCTYPE html>
<html lang="en" >

<head>
    <meta charset="UTF-8">
    <title>Reservation Confirmation: Table booking at 5 minuti</title>
</head>

<body>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <!--[if !mso]><!--><meta http-equiv="X-UA-Compatible" content="IE=edge">
    <!--<![endif]-->
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title></title>
    <style type="text/css">
        body{width:100% !important;-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;margin:0;padding:0;background-color:#677c67;}
        * {-webkit-font-smoothing:antialiased}
        .ExternalClass * {line-height:100%}
        table td {border-collapse:collapse; max-width:100% !important; word-break:break-word; -webkit-hyphens:auto; -moz-hyphens:auto; hyphens:auto; overflow:auto; white-space:normal;}
        .wlf {width:610px}
        @media only screen and (max-width:610px) {
            .full-width {width:100% !important}
            .t-none {display:none}
            .t-center-txt {text-align:center}
            .t-width {width:100% !important;max-width:100% !important;display:table !important}
        }
    </style>
</head>
<body>
<div style="display:none;font-size:1px;color:#333333;line-height:1px;max-height:0px;max-width:0px;opacity:0;overflow:hidden;">
    Reservation Confirmation: Table booking at 5 minuti
</div>
<div style="background-color:#677c67">
    <table width="100%" border="0" cellspacing="0" cellpadding="0"><tr><td background="">
        <!--[if mso]><table width="610" border="0" cellspacing="0" cellpadding="0" align="center"><tr><td><![endif]-->
        <table class="wlf full-width" width="100%" border="0" cellspacing="0" cellpadding="0" align="center" style="margin:0 auto;max-width:610px">
            <tr>
                <td width="5" style="font-size:1px;line-height:1px"> </td>
                <td>
                    <table width="100%" border="0" cellspacing="0" cellpadding="0" style="min-width:100%">
                        <tr>
                            <td height="20"> </td>
                        </tr>
                        <tr>
                            <td style="font-size:1px;line-height:1px"><img src="https://www.mytime.com/assets/email_assets/reengagement/corners-top.png" width="600" alt="" style="display:block;width:100%;max-width:600px;max-height:31px"></td>
                        </tr>
                    </table>

                    <table width="100%" border="0" cellspacing="0" cellpadding="0" style="min-width:100%">
                        <tr>
                            <td width="1" bgcolor="#a1a6a8" style="font-size:1px;line-height:1px"></td>
                            <td bgcolor="#ffffff">
                                <table width="100%" border="0" cellspacing="0" cellpadding="0" style="min-width:100%">
                                    <tr>
                                        <td width="5%" style="font-size:1px;line-height:1px"> </td>
                                        <td>
                                            <table width="100%" border="0" cellspacing="0" cellpadding="0" style="border-bottom:1px solid #e7e7e7;min-width:100%">
                                                <tr>
                                                    <td height="20"> </td>
                                                </tr>
                                                <tr>
                                                    <td>
                                                        <table width="100%" border="0" cellspacing="0" cellpadding="0" style="min-width:100%">
                                                            <tr>
                                                                <td style="font-size:0;text-align:center">
                                                                    <table class="t-width" width="100%" border="0" cellspacing="0" cellpadding="0" style="max-width:170px;display:inline-block;vertical-align:middle">
                                                                        <tr>
                                                                            <td height="10" style="font-size:1px;line-height:1px"> </td>
                                                                        </tr>
                                                                        <tr>
                                                                            <td align="center" style="width:170px; height:112px">
                                                                                <a href="https://www.facebook.com/5minutialesund/" target="_blank"><img src="https://espensv-5min.uials.no/assets/logo.png" width="130" height="112" alt="" style="display:block;border:none;max-height:100%;max-width:100%;"></a>
                                                                            </td>
                                                                        </tr>
                                                                        <tr>
                                                                            <td height="10" style="font-size:1px;line-height:1px"> </td>
                                                                        </tr>
                                                                    </table>
                                                                    <!--[if mso]></td><td width="360"><![endif]-->
                                                                    <table class="t-width" width="100%" border="0" cellspacing="0" cellpadding="0" style="display:inline-block; vertical-align:middle; max-width:360px;">
                                                                        <tr>
                                                                            <td class="t-none" width="20"> </td>
                                                                            <td>
                                                                                <table width="100%" border="0" cellspacing="0" cellpadding="0" style="min-width:100%">
                                                                                    <tr>
                                                                                        <td height="0" style="font-size:1px;line-height:1px"> </td>
                                                                                    </tr>
                                                                                    <tr>
                                                                                        <td align="left" class="t-center-txt" style="color:#4f4f4f;font-family:Verdana, Arial, sans-serif;font-size:20px;line-height:24px">5 Minuti</td>
                                                                                    </tr>
                                                                                    <tr>
                                                                                        <td height="15" style="font-size:1px;line-height:1px"> </td>
                                                                                    </tr>
                                                                                    <tr>
                                                                                        <td align="left" class="t-center-txt" style="color:#4f4f4f;font-family:Verdana, Arial, sans-serif;font-size:14px;line-height:18px">Kongens gate 14, 6002 Ålesund</td>
                                                                                    </tr>
                                                                                    <tr>
                                                                                        <td align="left" class="t-center-txt" style="color:#4f4f4f;font-family:Verdana, Arial, sans-serif;font-size:14px;line-height:18px">459 52 682</td>
                                                                                    </tr>
                                                                                    <tr>
                                                                                        <td height="10" style="font-size:1px;line-height:1px"> </td>
                                                                                    </tr>
                                                                                </table>
                                                                            </td>
                                                                            <td class="t-none" width="20"> </td>
                                                                        </tr>
                                                                    </table>
                                                                </td>
                                                            </tr>
                                                        </table>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td height="20"> </td>
                                                </tr>
                                            </table>

                                            <table width="100%" border="0" cellspacing="0" cellpadding="0" style="min-width:100%">
                                                <tr>
                                                    <td height="5"> </td>
                                                </tr>
                                                <tr>
                                                    <td style="color:#4f4f4f;font-family:Verdana, Arial, sans-serif;font-size:14px;line-height:20px">
                                                        <table width="100%" border="0" cellspacing="0" cellpadding="0">
                                                            <tr>
                                                                <td height="5"> </td>
                                                            </tr>

                                                            <tr>
                                                                <td style="color:#4f4f4f;font-family:Verdana, Arial, sans-serif;font-size:14px;line-height:20px">
                                                                    <table width="100%" border="0" cellspacing="0" cellpadding="0" style="border-collapse:collapse;">
                                                                        <tr>
                                                                            <td height="25"> </td>
                                                                        </tr>
                                                                        <tr>
                                                                            <td align="center" style="color:#09c064;font-family:Verdana, Arial, sans-serif;font-size:22px;line-height:26px;overflow-y:hidden">Your Reservation has been Confirmed!</td>
                                                                        </tr>
                                                                        <tr>
                                                                            <td height="35"> </td>
                                                                        </tr>
                                                                        <tr>
                                                                            <td align="center"><img src="https://www.mytime.com/assets/email_assets/pending_and_confirmation/a-c.png" width="364" alt="" style="display:block;width:100%;max-width:364px;max-height:58px"></td>
                                                                        </tr>
                                                                        <tr>
                                                                            <td height="20"> </td>
                                                                        </tr>
                                                                    </table>

                                                                </td>
                                                            </tr>

                                                            <tr>
                                                                <td height="10"> </td>
                                                            </tr>
                                                        </table>
                                                        <table width="100%" border="0" cellspacing="0" cellpadding="0">
                                                            <tr>
                                                                <td height="5"> </td>
                                                            </tr>

                                                            <tr>
                                                                <td style="color:#4f4f4f;font-family:Verdana, Arial, sans-serif;font-size:14px;line-height:20px">
                                                                    <p>Hi <span></span><span>${user.name}</span><span></span>,</p>
                                                                    <p>Reservation confirmed with <span></span><span>5 Minuti</span><span></span> on <span></span><span>${user.date} at  ${user.fromTime} to: ${user.toTime}</span><span></span>. Please find the details below:</p>
                                                                </td>
                                                            </tr>

                                                            <tr>
                                                                <td height="10"> </td>
                                                            </tr>
                                                        </table>
                                                        <table width="100%" border="0" cellspacing="0" cellpadding="0">
                                                            <tr>
                                                                <td height="5"> </td>
                                                            </tr>

                                                            <tr>
                                                                <td style="color:#4f4f4f;font-family:Verdana, Arial, sans-serif;font-size:14px;line-height:20px">

                                                                    <table width="100%" border="0" cellspacing="0" cellpadding="0">
                                                                        <tr>
                                                                            <td width="10%"> </td>
                                                                            <td>
                                                                                <table width="100%" border="0" cellspacing="0" cellpadding="0" style="border:1px solid #d6d6d6;border-radius:5px; box-shadow:0px 0px 4px 0px #cccccc;">
                                                                                    <tr>
                                                                                        <td>
                                                                                            <table width="100%" bgcolor="#146880" border="0" cellspacing="0" cellpadding="0" style="border-top-left-radius:5px;border-top-right-radius:5px;background-color:#146880;">
                                                                                                <tr>
                                                                                                    <td width="5%"> </td>
                                                                                                    <td>
                                                                                                        <table width="100%" border="0" cellspacing="0" cellpadding="0">
                                                                                                            <tr>
                                                                                                                <td height="20"> </td>
                                                                                                            </tr>
                                                                                                            <tr>
                                                                                                                <td align="center" style="color:#ffffff;font-family:Verdana, Arial, sans-serif;font-size:18px;line-height:22px;">Confirmed Time:</td>
                                                                                                            </tr>
                                                                                                            <tr>
                                                                                                                <td height="5" style="font-size:1px;line-height:1px"> </td>
                                                                                                            </tr>
                                                                                                            <tr>
                                                                                                                <td align="center" style="color:#ffffff;font-family:Verdana, Arial, sans-serif;font-size:18px;line-height:20px;overflow:hidden;">${user.date} at  ${user.fromTime} to: ${user.toTime}</td>
                                                                                                            </tr>
                                                                                                            <tr>
                                                                                                                <td height="20"> </td>
                                                                                                            </tr>
                                                                                                        </table>
                                                                                                    </td>
                                                                                                    <td width="5%"> </td>
                                                                                                </tr>
                                                                                            </table>
                                                                                            <table width="100%" border="0" cellspacing="0" cellpadding="0">
                                                                                                <tr>
                                                                                                    <td width="5%"> </td>
                                                                                                    <td>
                                                                                                        <table width="100%" border="0" cellspacing="0" cellpadding="0">
                                                                                                            <tr>
                                                                                                                <td height="20"> </td>
                                                                                                            </tr>
                                                                                                             <tr>
                                                                                                                <td style="color:#4f4f4f;font-family:Verdana, Arial, sans-serif;font-size:14px;line-height:20px">
                                                                                                                    Table: ${user.tableSelected}<br>
                                                                                                                    Duration: ${user.fromTime} to: ${user.toTime} <br>
                                                                                                                    Date: ${user.date} <br>
                                                                                                                    Staff: The 5 minuti family<br>
                                                                                                                </td>
                                                                                                            </tr>
                                                                                                            <tr>
                                                                                                                <td height="20" style="border-bottom:1px solid #a4a4a4"> </td>
                                                                                                            </tr>
                                                                                                            <tr>
                                                                                                                <td height="20"> </td>
                                                                                                            </tr>
                                                                                                            <tr>
                                                                                                                <td style="color:#319fb5;font-family:Verdana, Arial, sans-serif;font-size:18px;line-height:26px; text-decoration: none;"><a href="https://www.facebook.com/5minutialesund" target="_blank" style="color:#319fb5;font-family:Verdana, Arial, sans-serif;font-size:14px;line-height:26px; text-decoration: none;">5 Minuti</a></td>
                                                                                                            </tr>
                                                                                                            <tr>
                                                                                                                <td style="color:#4f4f4f;font-family:Verdana, Arial, sans-serif;font-size:14px;line-height:18px">
                                                                                                                    Ålesund<br> Kongens gate 14, 6002 Ålesund<br>
                                                                                                                    <a href="#" style="color:#4f4f4f;pointer-events:none;cursor:default;text-decoration:none">459 52 682</a>
                                                                                                                </td>
                                                                                                            </tr>
                                                                                                            <tr>

                                                                                                            <tr>
                                                                                                                <td height="20"> </td>
                                                                                                            </tr>
                                                                                                        </table>
                                                                                                    </td>
                                                                                                    <td width="5%"> </td>
                                                                                                </tr>
                                                                                            </table>
                                                                                        </td>
                                                                                    </tr>
                                                                                </table>
                                                                            </td>
                                                                            <td width="10%"> </td>
                                                                        </tr>
                                                                    </table>
                                                                    <br>


                                                                </td>
                                                            </tr>

                                                            <tr>
                                                                <td height="10"> </td>
                                                            </tr>
                                                        </table>
                                                        <table width="100%" border="0" cellspacing="0" cellpadding="0">
                                                            <tr>
                                                                <td height="5"> </td>
                                                            </tr>

                                                            <tr>
                                                                <td style="color:#4f4f4f;font-family:Verdana, Arial, sans-serif;font-size:14px;line-height:20px">


                                                                </td>
                                                            </tr>

                                                            <tr>
                                                                <td height="10"> </td>
                                                            </tr>
                                                        </table>
                                                         <tr>
                                                         <td><img src="https://i.imgur.com/zJwW6wC.png" ></td>
                                                         </tr>
                                                        <table width="100%" border="0" cellspacing="0" cellpadding="0">
                                                            <tr>
                                                                <td height="5"> </td>
                                                            </tr>

                                                            <tr>
                                                                <td style="color:#4f4f4f;font-family:Verdana, Arial, sans-serif;font-size:14px;line-height:20px">
                                                                    <p><b>Need to make changes to this reservation? Call us at 459 52 682</b>
                                                                    <p>Thank you for the reservation, we can't wait to see you!<br><span></span><span>5 Minuti</span><span></span> </p>
                                                                </td>
                                                            </tr>

                                                            <tr>
                                                                <td height="10"> </td>
                                                            </tr>
                                                        </table>

                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td height="5"> </td>
                                                </tr>
                                            </table>
                                        </td>
                                        <td width="5%" style="font-size:1px;line-height:1px"> </td>
                                    </tr>
                                </table>


                            </td>
                            <td width="1" bgcolor="#a1a6a8" style="font-size:1px;line-height:1px"></td>
                        </tr>
                    </table>

                    <table width="100%" border="0" cellspacing="0" cellpadding="0" style="min-width:100%">
                        <tr>
                            <td style="font-size:1px;line-height:1px"><img src="https://www.mytime.com/assets/email_assets/reengagement/corners-bottom.png" width="600" alt="" style="display:block;width:100%;max-width:600px;max-height:20px"></td>
                        </tr>
                        <tr>
                            <td height="20"> </td>
                        </tr>
                    </table>
                </td>
                <td width="5" style="font-size:1px;line-height:1px"> </td>
            </tr>
        </table>
        <!--[if mso]></td></tr></table><![endif]-->
    </td></tr></table>
</div>

</body>
</html>



</body>

</html>
        `, // html body
    });

    console.log("Message sent: %s", info.messageId);
    console.log("Preview URL: %s", nodemailer.getTestMessageUrl(info));
}

