const jwt = require('jsonwebtoken');
const randtoken = require('rand-token');
const passport = require('passport');
const JwtStrategy = require('passport-jwt').Strategy;
const ExtractJwt = require('passport-jwt').ExtractJwt;
const bcrypt = require('bcrypt');
const userSchema = require('../models/user');

require('dotenv').config();

const SECRET = process.env.SECRET_KEY;
const passportOpts = {
    jwtFromRequest: ExtractJwt.fromAuthHeaderAsBearerToken(),
    secretOrKey: SECRET
};

const refreshTokens = {};

/**
 * Ref: http://www.passportjs.org/packages/passport-jwt/
 */
passport.use(new JwtStrategy(passportOpts, function (jwtPayload, done) {
    const expirationDate = new Date(jwtPayload.exp * 1000);
    if (expirationDate < new Date()) {
        return done(null, false);
    }
    done(null, jwtPayload);
}));

passport.serializeUser(function (user, done) {
    done(null, user.username)
});

/**
 *
 * @param req object from body what is required. Username and password
 * @param res result, returns a JWT either as empty JWT or JWT key, depending of the result
 */
exports.login = (req, res) => {
    let fetchedUser;
    const {username, password} = req.body;
    const hash = bcrypt.hash(password, 10);
    const user = {
        username: process.env.usernameVariable, password: hash.password
    };
    const saltRounds = 10;
    const localVarPwd = process.env.passwordVariable;

    bcrypt.genSalt(10).then(salt => {
        bcrypt.hash(localVarPwd, salt).then(hash => {

            var admin = userSchema;
            const adminPassword = admin.findOne({username: 'Admin'}, function (err, adminuser) {
                bcrypt.compare(password, adminuser.password).then(result => {
                    if (result == true && username === process.env.usernameVariable ) {
                        const token = jwt.sign(
                            {username: process.env.usernameVariable, password: password},
                            process.env.SECRET_KEY);
                        const refreshToken = randtoken.uid(256);
                        refreshTokens[refreshToken] = username;
                        res.json({jwt: token, refreshToken: refreshToken});
                        console.log("Administrator logged in")
                    } else {
                        res.json({jwt: null, refreshToken: null})
                        console.log('Username or password are wrong')
                    }
                })
                return adminuser.password;
            });

        })
    })
}

/**
 * Ref: https://codeforgeek.com/refresh-token-jwt-nodejs-authentication/
 */
exports.logout = (req, res) => {
    const refreshToken = req.body.refreshToken;
    if (refreshToken in refreshTokens) {
        delete refreshTokens[refreshToken];
    }
    res.sendStatus(204);
}

exports.refresh = (req, res) => {
    const refreshToken = req.body.refreshToken;

    if (refreshToken in refreshTokens) {
        const user = {
            'username': refreshTokens[refreshToken],
            'role': 'admin'
        }
        const token = jwt.sign(user, SECRET, {expiresIn: 600});
        res.json({jwt: token})
    } else {
        res.sendStatus(401);
    }
}

