const mongoose = require("mongoose")
const bcrypt = require("bcryptjs")

/**
 * Ref: https://mongoosejs.com/docs/middleware.html
 */
const UserSchema = new mongoose.Schema({
    username: String,
    password: String
})

UserSchema.pre("save", function (next) {
    const user = this

    if (this.isModified("password") || this.isNew) {
        bcrypt.genSalt(10, function (saltError, salt) {
            if (saltError) {
                return next(saltError)
            } else {
                bcrypt.hash(user.password, salt, function(hashError, hash) {
                    if (hashError) {
                        return next(hashError)
                    }

                    user.password = hash
                    next()
                })
            }
        })
    } else {
        return next()
    }
})

/**
 * https://stackoverflow.com/questions/14588032/mongoose-password-hashing
 * @param password password
 * @param callback callback
 */
UserSchema.methods.comparePassword = function(password, callback) {
    bcrypt.compare(password, this.password, function(error, isMatch) {
        if (error) {
            return callback(error)
        } else {
            callback(null, isMatch)
        }
    })
}

module.exports = mongoose.model("User", UserSchema)
