const LocalStrategy = require('passport-local').Strategy
const bcrypt = require('bcrypt')

/**
 * Ref: https://forum.freecodecamp.org/t/mongodb-how-to-implement-passport-express-mongodb/393098
 * @param passport passport
 * @param getUserByEmail valid email
 * @param getUserById user by id
 */
function initialize(passport, getUserByEmail, getUserById) {
  const authenticateUser = async (email, password, done) => {
    const user = getUserByEmail(email)
    if (user == null) {
      return done(null, false, { message: 'No user with that email' })
    }

    try {
      if (await bcrypt.compare(password, user.password)) {
        return done(null, user)
      } else {
        return done(null, false, { message: 'Password incorrect' })
      }
    } catch (e) {
      return done(e)
    }
  }

  passport.use(new LocalStrategy({ usernameField: 'email' }, authenticateUser))
  passport.serializeUser((user, done) => done(null, user.id))
  passport.deserializeUser((id, done) => {
    return done(null, getUserById(id))
  })
}

module.exports = initialize