import {NgModule} from '@angular/core';
import {RouterModule, Routes} from '@angular/router';
import {ReservationListCurrentdayComponent} from './reservation-list-currentday/reservation-list-currentday.component';
import {ConfirmReservationComponent} from './03confirm-reservation/confirm-reservation.component';
import {ConfirmedReservationComponent} from './04confirmed-reservation/confirmed-reservation.component';
import {HomeComponent} from './home/home.component';
import {TableGUIComponent} from './02table-gui/table-gui.component';
import { LoginComponent } from './auth/containers/login/login.component';
import { AuthGuard } from './auth/guards/auth.guard';
import { ReservationListGuard } from './auth/guards/reservation-list.guard';
import { ReservationListCurrentdayGuard } from './auth/guards/reservation-list-currentday.guard';
import { AboutComponent } from './about/about.component';
import { ContactComponent } from './contact/contact.component';

/**
 * Ref: https://dev-academy.com/angular-jwt/
 */
const routes: Routes = [
  {path: '', component: HomeComponent},
  {path: 'auth/login', component: LoginComponent},
  {path: 'table-gui', component: TableGUIComponent},
  {path: 'confirm-reservation', component: ConfirmReservationComponent},
  {path: 'confirmed-reservation', component: ConfirmedReservationComponent},
  {path: 'about', component: AboutComponent},
  {path: 'contact', component: ContactComponent},
  {
    path: 'login',
    component: LoginComponent,
    canActivate: [AuthGuard]
  },
  {
    path: 'reservation-list',
    loadChildren: () => import('./00reservation-list/reservation-list.module').then(mod => mod.ReservationListModule),
    canActivate: [ReservationListGuard],
    canLoad: [ReservationListGuard]
  },
  {
    path: 'reservation-list-currentday',
    loadChildren: () => import('./reservation-list-currentday/reservation-list-currentday.module')
      .then(mod => mod.ReservationListCurrentdayModule),
    canActivate: [ReservationListCurrentdayGuard],
    canLoad: [ReservationListCurrentdayGuard]
  }
];

@NgModule({
  imports: [RouterModule.forRoot(routes)],
  exports: [RouterModule]
})
export class AppRoutingModule {
}

