import {LOCALE_ID, NgModule} from '@angular/core';
import {BrowserModule} from '@angular/platform-browser';
import {BrowserAnimationsModule} from '@angular/platform-browser/animations';
import {HttpClientModule} from '@angular/common/http';
import {FormsModule} from '@angular/forms';
import {MatTableModule} from '@angular/material/table';
import {MatProgressSpinnerModule} from '@angular/material/progress-spinner';
import {MatFormFieldModule} from '@angular/material/form-field';
import {MatInputModule} from '@angular/material/input';
import {MatButtonModule} from '@angular/material/button';
import {MatDatepickerModule} from '@angular/material/datepicker';
import {DateAdapter, MatNativeDateModule} from '@angular/material/core';
import {MatToolbarModule} from '@angular/material/toolbar';
import {MatGridListModule} from '@angular/material/grid-list';
import {MatSelectModule} from '@angular/material/select';
import {NavbarComponent} from './navbar/navbar.component';
import {MatCardModule} from '@angular/material/card';
import {MatIconModule} from '@angular/material/icon';
import {MatExpansionModule} from '@angular/material/expansion';
import {MatMenuModule} from '@angular/material/menu';
import {MatCheckboxModule} from '@angular/material/checkbox';
import {MatTooltipModule} from '@angular/material/tooltip';
import {AppRoutingModule} from './app-routing.module';
import {AppComponent} from './app.component';
import {HomeComponent} from './home/home.component';
import {ReservationComponent} from './01reservation/reservation.component';
import {TableGUIComponent} from './02table-gui/table-gui.component';
import {ConfirmReservationComponent} from './03confirm-reservation/confirm-reservation.component';
import {ConfirmedReservationComponent} from './04confirmed-reservation/confirmed-reservation.component';
import {MatDialogModule} from '@angular/material/dialog';
import {PopupWarningComponent} from './popup-attention/popup-attention.component';
import {CustomDateAdapter} from './01reservation/custom-date-adapter';
import {LayoutModule} from '@angular/cdk/layout';
import {MatSidenavModule} from '@angular/material/sidenav';
import {MatListModule} from '@angular/material/list';
import {MatSortModule} from '@angular/material/sort';
import {MatPaginatorModule} from '@angular/material/paginator';
import {MatStepperModule} from '@angular/material/stepper';
import { NgxCaptchaModule } from 'ngx-captcha';
import {ReactiveFormsModule} from '@angular/forms';
import {PopupIncomingReservationComponent} from './popup-incoming-reservation/popup-incoming-reservation.component';
import {WebsocketService} from './websocket.service';
import { AuthModule } from './auth/auth.module';
import { PopupDeleteComponent } from './popup-delete/popup-delete.component';
import {PopupReservationComponent} from './popup-reservation/popup-reservation.component';
import {ServiceWorkerModule} from '@angular/service-worker';
import {environment} from '../environments/environment';
import { ContactComponent } from './contact/contact.component';
import { AboutComponent } from './about/about.component';

@NgModule({
  declarations: [
    AppComponent,
    HomeComponent,
    ReservationComponent,
    TableGUIComponent,
    NavbarComponent,
    PopupWarningComponent,
    ConfirmedReservationComponent,
    ConfirmReservationComponent,
    PopupDeleteComponent,
    ContactComponent,
    AboutComponent
  ],
  /**
   * Ref: https://stackoverflow.com/questions/56390787/angular-8-error-error-no-component-factory-found
   */
  entryComponents: [PopupWarningComponent, PopupIncomingReservationComponent, PopupDeleteComponent, PopupReservationComponent],
  imports: [
    BrowserModule,
    AppRoutingModule,
    BrowserAnimationsModule,
    MatTableModule,
    MatProgressSpinnerModule,
    MatFormFieldModule,
    MatInputModule,
    MatButtonModule,
    MatDatepickerModule,
    MatNativeDateModule,
    MatToolbarModule,
    HttpClientModule,
    FormsModule,
    MatSelectModule,
    MatGridListModule,
    MatSortModule,
    MatCardModule,
    MatIconModule,
    MatDialogModule,
    MatExpansionModule,
    MatMenuModule,
    LayoutModule,
    MatSidenavModule,
    MatListModule,
    MatCheckboxModule,
    MatTooltipModule,
    MatPaginatorModule,
    MatStepperModule,
    ReactiveFormsModule,
    AuthModule,
    HttpClientModule,
    NgxCaptchaModule,
    ReactiveFormsModule,
    ServiceWorkerModule.register('ngsw-worker.js', {
      enabled: environment.production,
      registrationStrategy: 'registerImmediately'
    }),
  ],
  providers: [
    {provide: LOCALE_ID, useValue: 'en-GB'},
    {provide: DateAdapter, useClass: CustomDateAdapter},
    {provide: WebsocketService}
  ],
  bootstrap: [AppComponent]
})
export class AppModule {
}
